@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'weaken';
 
-our $VERSION   = '0.71';
+our $VERSION   = '0.72';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -43,7 +43,7 @@ sub wrap {
     ($params{package_name} && $params{name})
         || confess "You must supply the package_name and name parameters $UPGRADE_ERROR_TEXT";
 
-    my $self = (ref($class) || $class)->_new(\%params);
+    my $self = $class->_new(\%params);
 
     weaken($self->{associated_metaclass}) if $self->{associated_metaclass};
 
@@ -121,6 +121,11 @@ sub original_fully_qualified_name {
         : $self->fully_qualified_name;
 }
 
+sub execute {
+    my $self = shift;
+    $self->body->(@_);
+}
+
 # NOTE:
 # the Class::MOP bootstrap
 # will create this for us
@@ -163,10 +168,8 @@ to this class.
 =item B<wrap ($code, %params)>
 
 This is the basic constructor, it returns a B<Class::MOP::Method>
-instance which wraps the given C<$code> reference. You can also
-set the C<package_name> and C<name> attributes using the C<%params>.
-If these are not set, then thier accessors will attempt to figure
-it out using the C<Class::MOP::get_code_info> function.
+instance which wraps the given C<$code> reference. You must also set
+the C<package_name> and C<name> attributes in C<%params>.
 
 =item B<clone (%params)>
 
@@ -246,6 +249,17 @@ Disassociates the method from the metaclass
 
 =back
 
+=head2 Miscellaneous
+
+=over 4
+
+=item B<execute>
+
+Executes the method. Be sure to pass in the instance, since the
+method expects it.
+
+=back
+
 =head1 AUTHORS
 
 Stevan Little E<lt>stevan@iinteractive.comE<gt>
