@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken', 'looks_like_number';
 
-our $VERSION   = '0.71';
+our $VERSION   = '0.72';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -52,6 +52,8 @@ sub _new {
     }, $class;
 }
 
+sub can_be_inlined { 1 }
+
 ## accessors
 
 sub options              { (shift)->{'options'}              }
@@ -190,7 +192,7 @@ Class::MOP::Method::Constructor - Method Meta Object for constructors
   );
 
   # calling the constructor ...
-  $constructor->body->($metaclass->name, %params);
+  $constructor->body->execute($metaclass->name, %params);
 
 =head1 DESCRIPTION
 
@@ -227,6 +229,12 @@ metaclass which is passed into C<new>.
 This returns a boolean, but since constructors are very rarely
 not inlined, this always returns true for now.
 
+=item B<can_be_inlined>
+
+This method always returns true in this class. It exists so that
+subclasses (like in Moose) can override and do some sort of checking
+to determine whether or not inlining the constructor is safe.
+
 =item B<initialize_body>
 
 This creates the code reference for the constructor itself.
